function bcs = self_similar_rayleigh_gans(wavelength, dielectric_const, D, ...
                                          volume, kappa, beta, gamma)
%SELF_SIMILAR_RAYLEIGH_GANS  
%   Compute the backscatter cross section of an aggregate particle using the
%   Self-Similar Rayleigh-Gans Approximation
%
%   bcs = self_similar_rayleigh_gans(wavelength, dielectric_const, D, ...
%                                    volume, kappa, beta, gamma)
%   where the arguments are:
%     bcs                  Backscatter cross-section (m2)
%     wavelength           Wavelength of radiation (m)
%     dielectric_const     Dielectric constant of material (complex)
%     D                    Particle size in direction of propagation (m)
%     volume               Volume of material (m3)
%     kappa                Kurtosis parameter describing mean structure
%     beta                 Prefactor of power-law describing fluctuations
%     gamma                Exponent of power-law describing fluctuations
%
%   The input variables beta and gamma must be scalars, but any of the others
%   may be vectors or scalars, provided that any vectors are the same
%   length, and D is also a vector. The output backscatter cross section
%   will have the same size as D.
%
%   This function is particularly suitable for computing the millimetre-wave
%   backscatter cross-section of ice and snow aggregates. Note that the
%   input dielectric constant is the value for solid ice and the input
%   volume is the volume of solid ice within the particle.
%
%   Note that the output is sometimes referred to as radar cross-section and
%   has units of m2, rather than in some conventions where backscatter
%   cross-section has units m2 sr-1 and is a factor of 4pi smaller.
%
%   For further information on the meaning of the arguments, see:
%     Hogan, R. J., and C. D. Westbrook, 2014: Equation for the microwave
%     backscatter cross section of aggregate snowflakes using the
%     Self-Similar Rayleigh-Gans Approximation. J. Atmos. Sci., in press.
%   This function essentially implements Eq. 12.
%
%   This file was written by Robin Hogan, but no copyright is asserted: this
%   file is in the public domain.  Therefore, copying and distribution of
%   this file, with or without modification, and merging all or part of this
%   file into other works, are permitted in any medium without royalty.
%   This file is offered as-is, without any warranty.

% Dielectric factor 
K2 = abs(((dielectric_const-1.0)./(dielectric_const+2.0))).^2;

% Wavenumber
k = 2.*pi./wavelength;

% Electrical size
x = k.*D;

% Factor outside the braces in Eq. 12 of Hogan and Westbrook
prefactor = 9.0.*pi.*(k.*k).^2.*K2.*volume.*volume./16.0;

% First term in the braces of Eq. 12 representing the mean structure
term1 = cos(x) ...
    .*( (1.0+kappa./3.0).*(1.0./(2.0.*x+pi) - 1.0./(2.0.*x-pi)) ...
        -kappa.*(1.0./(2.0.*x+3.0.*pi) - 1.0./(2.0.*x-3.0.*pi)) );
term1 = term1.*term1;

% Initialize backscatter cross-section
bcs = zeros(size(D));

% Loop over particles of different sizes
for ii = 1:length(D);

  % Initialize the summation in the second term in the braces of Eq. 12
  sum = 0.0;

  % Decide how many terms are needed
  jmax = floor(5.*x(ii)./pi + 1.0);

  % Evaluate summation
  for j = 1:jmax
    sum = sum + (2.0.*j).^-gamma .* sin(x(ii)).^2 ...
          .*(1.0./(2.0.*(x(ii)+pi.*j)).^2 + 1.0./(2.0.*(x(ii)-pi.*j)).^2);
  end

  % Put the terms together
  bcs(ii) = prefactor(ii).*(term1(ii) + beta.*sum);
end
